@@ -41,12 +41,21 @@ fn main() {
                         .takes_value(false)
                         .help("Build artifacts in release mode, with optimizations"),
                 )
+                .arg(Arg::new("package").short('p').long("package").takes_value(true).help("Build only the specified package."))
+                .arg(Arg::new("all-targets").long("all-targets").takes_value(false).help("Build all targets."))
+                .arg(Arg::new("workspace").long("workspace").takes_value(false).help("Build all members in the workspace."))
                 .arg(Arg::new("simd128").long("simd128").takes_value(false).help("Use 128-bit SIMD instruction set for WASM")),
         )
         .get_matches();
 
     if let Some(cmd) = matches.subcommand_matches("build") {
-        build(BuildOpts { release: cmd.is_present("release"), use_simd128: cmd.is_present("simd128") });
+        build(BuildOpts {
+            release: cmd.is_present("release"),
+            use_simd128: cmd.is_present("simd128"),
+            all_targets: cmd.is_present("all-targets"),
+            workspace: cmd.is_present("workspace"),
+            package: cmd.value_of("package").unwrap_or("").to_string(),
+        });
     }
 
     #[cfg(not(target_arch = "wasm32"))]
@@ -63,16 +72,33 @@ fn main() {
 struct BuildOpts {
     release: bool,
     use_simd128: bool,
+    all_targets: bool,
+    workspace: bool,
+    package: String,
 }
 
 fn build(opts: BuildOpts) {
     println!("    Running cargo build");
 
     let mut args = vec!["+nightly-2022-01-18", "build", "--target=wasm32-unknown-unknown", "-Zbuild-std=std,panic_abort"];
+
     if opts.release {
         args.push("--release");
     }
 
+    if opts.workspace {
+        args.push("--workspace");
+    }
+
+    if opts.all_targets {
+        args.push("--all-targets");
+    }
+
+    if !opts.package.is_empty() {
+        args.push("-p");
+        args.push(&opts.package);
+    }
+
     let rust_flags = {
         let mut flags = vec![];
         if opts.use_simd128 {
